decode_multikey

Function decode_multikey 

pub fn decode_multikey(key: &str) -> Result<Vec<u8>, EncodingError>
Decode a multikey string (multibase + multicodec encoded)

Returns just the key bytes without the multicodec prefix. This is the inverse of how keys are encoded in DID documents (publicKeyMultibase).