encode_multikey

Function encode_multikey 

pub fn encode_multikey(codec: u64, key_bytes: &[u8]) -> String
Encode key bytes with a multicodec prefix as a multibase (base58btc) string

This is the inverse of decode_multikey. The result is suitable for use as a DID key identifier or publicKeyMultibase value.